=========
History
=========
v0.6.0
------
* New methods added to `TradeBook` object
 * mtm - to calculate mtm for open positions
 * clear - to clear the existing entries
 * helper attributes for positions
* `order_fill_price` method added to utils to simulate order quantity

v0.5.1
------
* Simple bug fixes added

v0.5.0
------
* `OptionExpiry` class added to calculate option payoffs based on expiry

v0.4.0
-------
* Brokers module deprecation warning added
* Options module revamped

v0.3.0 (2019-03-15)
--------------------
* More helper functions added to utils
* Tradebook class enhanced
* A Meta class added for event based simulation

v0.2.0 (2018-12-26)
--------------------
* Backtest from different formats added
* Rolling function added


v0.1.0. (2018-10-13)
----------------------

* First release on PyPI
